diff tools/lib64gfx.h @ 2116:b49d7cb20a73

Implement initial ECM support in charmap decoding.
author Matti Hamalainen <ccr@tnsp.org>
date Sun, 26 May 2019 02:45:44 +0300
parents 27cf33c3a646
children 05a6e00b09d0
line wrap: on
line diff
--- a/tools/lib64gfx.h	Sun May 26 02:44:34 2019 +0300
+++ b/tools/lib64gfx.h	Sun May 26 02:45:44 2019 +0300
@@ -53,10 +53,13 @@
 {
     D64_FMT_HIRES        = 0x0000, // Hi-res
     D64_FMT_MC           = 0x0001, // MultiColor
-    D64_FMT_ILACE        = 0x0002, // Interlace
-    D64_FMT_FLI          = 0x0004, // FLI
-    D64_FMT_CHAR         = 0x0008, // Character mode
-    D64_FMT_BORDER       = 0x0010, // Uses border area
+    D64_FMT_ECM          = 0x0002, // ECM mode (applies only to character mode)
+    D64_FMT_MASK         = 0x000f,
+
+    D64_FMT_ILACE        = 0x0010, // Interlace
+    D64_FMT_FLI          = 0x0020, // FLI
+    D64_FMT_CHAR         = 0x0040, // Character mode
+    D64_FMT_BORDER       = 0x0080, // Uses border area
 };